@@ -286,8 +286,8 @@ GAMGI_CHEM_FILTER_IDENTICAL, GAMGI_CHEM_FILTER_NONE };
 #define GAMGI_CHEM_ORBITAL_STEP 0.01
 
 /*************************************************************
- * used to build dotted H orbitals: default density,         *
- * default number of points / n (main quantum number),       *
+ * used to build wired H orbitals: default density,          *
+ * default number of points per n (main quantum number),     *
  * number of acceptable bad points (below density threshold) *
  *************************************************************/
 
@@ -295,6 +295,16 @@ GAMGI_CHEM_FILTER_IDENTICAL, GAMGI_CHEM_FILTER_NONE };
 #define GAMGI_CHEM_ORBITAL_POINTS   50000
 #define GAMGI_CHEM_ORBITAL_BAD       1000
 
+/************************************************************
+ * used to build solid H orbitals: default number of slices *
+ * per octant, maximum number of slices per octant, initial *
+ * size and increment for points arrays                     *
+ ************************************************************/
+
+#define GAMGI_CHEM_ORBITAL_SLICES      50
+#define GAMGI_CHEM_ORBITAL_SLICES_MAX 150
+#define GAMGI_CHEM_ORBITAL_SEGMENT    100
+
 /***************************************
  * default orbital origin, orientation *
  ***************************************/
