@@ -157,7 +157,13 @@ void (*draw) (struct _gamgi_orbital *);
 
 int n, l, m;
 double charge;
+
+/*****************
+ * sampling data *
+ *****************/
+
 double radius, density;
+int sampling;
 
 /**************
  * array data *
