@@ -1025,9 +1025,9 @@ if (GAMGI_EXPAT_ID_GROUP == TRUE)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-/*****************
- * Polytope page *
- *****************/
+/*************
+ * Type page *
+ *************/
 
 if (group->type == GAMGI_CHEM_POLYTOPE)
   gamgi_expat_export_attribute (fp, "type=\"polytope\"", depth, column, error);
@@ -1191,6 +1191,13 @@ if (GAMGI_EXPAT_ID_CLUSTER == TRUE)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
+/*************
+ * Type page *
+ *************/
+
+if (cluster->type == GAMGI_CHEM_POLYTOPE)
+  gamgi_expat_export_attribute (fp, "type=\"polytope\"", depth, column, error);
+
 /*****************
  * Position data *
  *****************/
@@ -1250,8 +1257,11 @@ if (fabs (euler[0] - 0.0) > GAMGI_MATH_TOLERANCE
  * dots,faces,borders (optional) *
  *********************************/
 
-if (cluster->dots == TRUE)
-  gamgi_expat_export_attribute (fp, "dots=\"yes\"", depth, column, error);
+if (cluster->n_dots > 0)
+  {
+  sprintf (string, "dots=\"%d\"", cluster->n_dots);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
 
 if (cluster->faces == TRUE)
   gamgi_expat_export_attribute (fp, "faces=\"yes\"", depth, column, error);
