@@ -631,6 +631,9 @@ static void static_list (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *label, *button;
+gamgi_bool *sensitive;
+
+sensitive = (gamgi_bool *) g_object_get_data (G_OBJECT (dialog), "sensitive_reference");
 
 label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_direction");
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
@@ -642,6 +645,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
    **************************************/
 
   gtk_label_set_text (GTK_LABEL (label), "Direction");
+  sensitive[STATIC_REFERENCE_CELL] = TRUE;
+  sensitive[STATIC_REFERENCE_ATOMS] = TRUE;
   }
 else
   {
@@ -650,6 +655,8 @@ else
    **************************************************/
 
   gtk_label_set_text (GTK_LABEL (label), "Name");
+  sensitive[STATIC_REFERENCE_CELL] = FALSE;
+  sensitive[STATIC_REFERENCE_ATOMS] = FALSE;
   static_reset (window);
   }
 }
@@ -1391,6 +1398,19 @@ if (new == TRUE)
 
   if (direction->reference == GAMGI_ENGINE_CELL)
     {
+    /******************************************************************
+     * Direction Create: direction is just a template, removed in the *
+     * end, used to copy data to direction_new, the real direction    *
+     *                                                                *
+     * Direction Modify: direction is the real direction to modify    *
+     *                                                                *
+     * direction->object.object is used here as a flag to distinguish *
+     * between the two cases. direction->object.object can be used    *
+     * because direction is always unlinked at this stage             *
+     ******************************************************************/
+
+    direction->object.object = GAMGI_CAST_OBJECT cell;
+
     /****************************************
      * this is a crystallographic direction *
      ****************************************/
@@ -1413,7 +1433,6 @@ if (new == TRUE)
       while (dlist != NULL)
         dlist = gamgi_engine_dlist_remove_start (dlist);
       }
-    gamgi_engine_remove_direction (direction);
     }
 
   if (direction->reference == GAMGI_ENGINE_ATOM)
@@ -1991,6 +2010,11 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
+sensitive = gamgi_gtk_dialog_sensitive_create (3);
+g_object_set_data (G_OBJECT (dialog), "sensitive_reference", sensitive);
+gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo),
+renderer, gamgi_gtk_dialog_sensitive_scan, sensitive, free);
+
 /********
  * Cell *
  ********/
