@@ -200,6 +200,30 @@ else
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 }
 
+static void static_style (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *combo;
+GtkWidget *entry;
+char token[GAMGI_ENGINE_TOKEN];
+int n, style;
+
+/************************
+ * set default sampling *
+ ************************/
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_n");
+n = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
+style = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_sampling");
+sprintf (token, "%d", gamgi_chem_orbital_sampling (n, style));
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+}
+
 static void static_m (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
@@ -220,13 +244,11 @@ l = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_m");
 m = gtk_combo_box_get_active (GTK_COMBO_BOX (combo)) - 5;
 
-/********************************
- * set default number of points *
- ********************************/
+/************************
+ * set default sampling *
+ ************************/
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_points");
-sprintf (token, "%d", gamgi_chem_orbital_points (n));
-gtk_entry_set_text (GTK_ENTRY (entry), token);
+static_style (NULL, window);
 
 /**********************
  * set default radius *
@@ -358,18 +380,26 @@ if (gamgi_io_token_double_scan (name,
   return;
   }
 
-/******************************************************************
- * Volume page: get style, points, radius, density, octants, axes *
- ******************************************************************/
+/********************************************************************
+ * Volume page: get style, sampling, radius, density, octants, axes *
+ ********************************************************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
 orbital->style = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_points");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_sampling");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_int_scan (name, &orbital->n_points, 1, INT_MAX) == FALSE)
+if (gamgi_io_token_int_scan (name, &orbital->sampling, 1, INT_MAX) == FALSE)
   {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid number of points", window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid sampling data", window);
+  gamgi_engine_remove_orbital (orbital);
+  return;
+  }
+
+if (orbital->style == GAMGI_MESA_SOLID &&
+orbital->sampling > GAMGI_CHEM_ORBITAL_SLICES_MAX)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid sampling data", window);
   gamgi_engine_remove_orbital (orbital);
   return;
   }
@@ -379,7 +409,7 @@ name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_double_scan (name, &orbital->radius,
 GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
   {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid scanning radius", window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid sampling radius", window);
   gamgi_engine_remove_orbital (orbital);
   return;
   }
@@ -388,7 +418,7 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_density");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_double_scan (name, &orbital->density, 0.0, 1.0) == FALSE)
   {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid probability density", window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid probability density threshold", window);
   gamgi_engine_remove_orbital (orbital);
   return;
   }
@@ -397,7 +427,7 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_seed");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &seed, 1, INT_MAX) == FALSE)
   {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid seed data", window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid sampling seed", window);
   gamgi_engine_remove_orbital (orbital);
   return;
   }
@@ -689,7 +719,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), token);
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_MESA_WIRED - 1);
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_points");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_sampling");
 sprintf (token, "%d", GAMGI_CHEM_ORBITAL_POINTS);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 
@@ -1126,6 +1156,7 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+g_signal_connect (combo, "changed", G_CALLBACK (static_style), window);
 g_object_set_data (G_OBJECT (dialog), "combo_style", combo);
 gtk_widget_show (combo);
 
@@ -1141,9 +1172,9 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
-/*******************
- * Density, Points *
- *******************/
+/*********************
+ * Density, Sampling *
+ *********************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
@@ -1172,7 +1203,7 @@ hbox_left_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left_left);
 
-label = gtk_label_new ("Points");
+label = gtk_label_new ("Sampling");
 gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
@@ -1180,7 +1211,7 @@ entry = gtk_entry_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
-g_object_set_data (G_OBJECT (dialog), "entry_points", entry);
+g_object_set_data (G_OBJECT (dialog), "entry_sampling", entry);
 gtk_widget_show (entry);
 
 /****************
