@@ -115,4 +115,10 @@ GAMGI_MATH_POLYTOPE_3, GAMGI_MATH_POLYTOPE_4 };
 #define GAMGI_MATH_DECIMAL_ABUNDANCE   4
 #define GAMGI_MATH_DECIMAL_DECAY       2
 
+/*************************************
+ * starting seed in random processes *
+ *************************************/
+
+#define GAMGI_MATH_SEED 1
+
 #endif
