@@ -328,6 +328,22 @@ GAMGI_MESA_SELECT_RESIZE };
 #define GAMGI_MESA_BOND_G 0.8
 #define GAMGI_MESA_BOND_B 0.0
 
+/**************************
+ * default orbital colors *
+ **************************/
+
+#define GAMGI_MESA_ORBITAL_BASE_R 1.0
+#define GAMGI_MESA_ORBITAL_BASE_G 0.5
+#define GAMGI_MESA_ORBITAL_BASE_B 0.0
+
+#define GAMGI_MESA_ORBITAL_PHASE_R 0.5
+#define GAMGI_MESA_ORBITAL_PHASE_G 0.5
+#define GAMGI_MESA_ORBITAL_PHASE_B 1.0
+
+#define GAMGI_MESA_ORBITAL_FRAME_R 1.0
+#define GAMGI_MESA_ORBITAL_FRAME_G 1.0
+#define GAMGI_MESA_ORBITAL_FRAME_B 1.0
+
 /**************************************************************************
  * Width recommended by Plotutils (the GNU package) to render western     *
  * Hershey fonts. They say:                                               *
@@ -420,6 +436,7 @@ GAMGI_MESA_SELECT_RESIZE };
  **********************************/
 
 #define GAMGI_MESA_TEXT_WEIGHT      5
+#define GAMGI_MESA_ORBITAL_WEIGHT   3
 #define GAMGI_MESA_ATOM_WEIGHT      1
 #define GAMGI_MESA_DIRECTION_WEIGHT 2
 #define GAMGI_MESA_PLANE_WEIGHT     3
