@@ -99,14 +99,24 @@ glMultMatrixd (rotate);
 
 dots = orbital->dots;
 
-glLineWidth (4.0);
-if (dots[1] > 0)
-  { glColor3fv (orbital->base);
-    gamgi_mesa_render_points (dots[1], orbital->points + 3 * dots[0]); }
-if (dots[2] > 0)
-  { glColor3fv (orbital->phase);
-    gamgi_mesa_render_points (dots[2], orbital->points + 3 * dots[0] + 3 * dots[1]); }
-glLineWidth (1.0);
+if (orbital->style == GAMGI_MESA_WIRED)
+  {
+  glLineWidth (4.0);
+  if (dots[1] > 0)
+    { glColor3fv (orbital->base);
+      gamgi_mesa_render_points (dots[1], orbital->points + 3 * dots[0]); }
+  if (dots[2] > 0)
+    { glColor3fv (orbital->phase);
+      gamgi_mesa_render_points (dots[2], orbital->points + 3 * dots[0] + 3 * dots[1]); }
+  glLineWidth (1.0);
+  }
+else
+  {
+  glDisable (GL_CULL_FACE);
+  glColor3fv (orbital->base);
+  gamgi_mesa_render_triangles (dots[1] / 3, orbital->points + 3 * dots[0]);
+  glEnable (GL_CULL_FACE);
+  }
 
 if (dots[0] > 0)
   { glColor3fv (orbital->frame);
